#US county-level agricultural crop production typology building
#Script 1/2
##Description: Wrangling USDA QuickStats NASS data for 21 crops
#Author: Courtney Hammond Wagner
#email: courtney.hammond@uvm.edu
#Date revised: 5/15/2019

#############################
#Packages
#############################
library(reshape2)
library(dplyr)
library(tidyr)
library(ggplot2)

##################################################################
###Import all files needed
#################################################################

#Crop data, downloaded from USDA NASS Quickstats database in batches
  #CSV file names below reflect the crops downloaded together in batches
  #For details of selection of data items to download from Quick Stats,
  #see Hammond Wagner et al. (2019)
d <- read.csv("apples_barley_canola.csv")
d2<- read.csv("drybeans_corngrain_cornsilage_cotton.csv")
d3 <- read.csv("hay_alfalfa_oranges_peanuts_potatoes.csv")
d4 <- read.csv ("rice_sorghum_soybeans_sugarbeats_sugarcane.csv")
d5 <- read.csv("sunflower_sweetcorn_tobacco_wheat.csv")

#Counties to drop based on assessment in ArcGIS using NLCD data
  #as described in Hammond Wagner et al. (2019)
todrop <- read.csv("PI_and_PRECIP_AgLand_only_11-1-18.csv")

#2012 State total harvest area for each of the 21 commodities
state<- read.csv("State_total_area_per_crop.csv")

#2002 and 2007 state total acres per crop for linear fill
state_total_0702 <- read.csv("USDA_NASS_State_Total_Harvested_Acres_2012_2007_2002.csv")

#2012 County total cropland (all US counties)
county<- read.csv("county_total_cropland.csv")

#2002 and 2007 state total acres per crop for linear fill
county_total_0702 <- read.csv("USDA_County_total_harvested_acres_2007_2002.csv")


#Data for checks
######Check 1 - state total acreage
state_rep_total_acres<- read.csv("USDA_NASS_State_Total_Harvested_Acres.csv")


##################################################################
###Crop data: subset columns, rbind data together into longform
#################################################################
keep_col <- c("State","State.ANSI","County","County.ANSI","Data.Item","Value")
d_2 <- d[,keep_col]
d2_2 <- d2[,keep_col]
d3_2 <- d3[,keep_col]
d4_2 <- d4[,keep_col]
d5_2 <- d5[,keep_col]

#long_data crop by county
long_data_raw <- rbind(d_2, d2_2, d3_2, d4_2, d5_2)
head(long_data_raw)
rm("d","d_2","d2","d2_2","d3","d3_2","d4","d4_2","d5","d5_2")

#Remove Alaska & Hawaii counties (focus on contiguous US)
#View(long_data[which(long_data$State.ANSI == 2),])
alaska <-which(long_data_raw$State.ANSI == 2)
long_data <- long_data_raw[-alaska, ]
#View(long_data[which(long_data$State.ANSI == 15),])
hawaii <-which(long_data$State.ANSI == 15)
long_data <- long_data[-hawaii, ]
rm(alaska, hawaii)

#Create an aggregate ANSI Variable
long_data$State.ANSI<- formatC(long_data$State.ANSI, width = 2, format = "d", flag = "0")
long_data$County.ANSI <- formatC(long_data$County.ANSI, width = 3, format = "d", flag = "0")
long_data$ANSI<- paste(long_data$State.ANSI, long_data$County.ANSI, sep = "")
long_data$ANSI<- as.factor(long_data$ANSI)



#Remove counties with low cropland
#Drop counties that don't have sufficient agland to be considered (PI and Precip)
#172 counties to drop:
#length(which(todrop$MEAN_PRECIP == "<Null>"))
todrop <- todrop[which(todrop$MEAN_PRECIP == "<Null>"),]
todrop_list <- todrop$GEOID
todrop_list<- formatC(todrop_list, width = 5, format = "d", flag = "0")
todrop_df<- long_data[(long_data$ANSI %in% todrop_list),]
#nrow(todrop_df)
todrop_list_2 <- unique(todrop_df$ANSI)
#134 counties are dropped  - dropped counties are in todrop_df
#Check to make sure subset works:
#a <- nrow(long_data)
#b <- nrow(subset(long_data, !(long_data$ANSI %in% todrop_list_2)))
# a-b
long_data <- subset(long_data, !(long_data$ANSI %in% todrop_list_2))

rm(todrop, todrop_df, todrop_list, todrop_list_2)


#Rename Data.Items:
#Match variable names in reported
long_data$Data.Item <- ifelse(long_data$Data.Item == "APPLES - ACRES BEARING","apples",
                         ifelse(long_data$Data.Item == "BARLEY - ACRES HARVESTED" ,"barley",
                          ifelse(long_data$Data.Item == "BEANS, DRY EDIBLE, (EXCL LIMA) - ACRES HARVESTED","beans",
                           ifelse(long_data$Data.Item == "CANOLA - ACRES HARVESTED","canola",
                            ifelse(long_data$Data.Item == "CORN, GRAIN - ACRES HARVESTED","corn_grain",
                             ifelse(long_data$Data.Item == "CORN, SILAGE - ACRES HARVESTED","corn_silage",
                              ifelse(long_data$Data.Item == "COTTON - ACRES HARVESTED","cotton",
                               ifelse(long_data$Data.Item == "HAY - ACRES HARVESTED","hay",
                                ifelse(long_data$Data.Item == "HAY, ALFALFA - ACRES HARVESTED","alfalfa",
                                ifelse(long_data$Data.Item == "ORANGES - ACRES BEARING","oranges",
                                ifelse(long_data$Data.Item ==  "PEANUTS - ACRES HARVESTED","peanuts",
                               ifelse(long_data$Data.Item == "POTATOES - ACRES HARVESTED","potatoes",
                              ifelse(long_data$Data.Item == "RICE - ACRES HARVESTED","rice",
                             ifelse(long_data$Data.Item == "SORGHUM, GRAIN - ACRES HARVESTED","sorghum",
                           ifelse(long_data$Data.Item == "SOYBEANS - ACRES HARVESTED","soybeans",
                          ifelse(long_data$Data.Item == "SUGARBEETS - ACRES HARVESTED","sugarbeets",
                         ifelse(long_data$Data.Item == "SUGARCANE, SUGAR - ACRES HARVESTED","sugarcane",
                        ifelse(long_data$Data.Item == "SUNFLOWER - ACRES HARVESTED","sunflower",
                       ifelse(long_data$Data.Item == "SWEET CORN - ACRES HARVESTED","sweet_corn",
                     ifelse(long_data$Data.Item == "TOBACCO - ACRES HARVESTED","tobacco",
                  ifelse(long_data$Data.Item == "WHEAT - ACRES HARVESTED","wheat","NA")))))))))))))))))))))




##########################
#Dealing with (D) and (Z)
##########################
#split dataframe into three, one with (D), (Z) and one with disclosed
#Change (z) to zero, recombine with long_data_disclosed
long_data_undisclosed <- long_data%>%
  filter(Value == " (D)")
long_data_undisclosed_z <- long_data%>%
  filter(Value == " (Z)")
long_data_disclosed <- long_data%>%
  filter(Value != " (D)" & Value != " (Z)")
long_data_disclosed$Value <- as.numeric(gsub(",","",long_data_disclosed$Value))

#Change (D) into -99, (z) to 0

long_data_undisclosed$Value <- -99
long_data_undisclosed_z$Value <- 0

#Recombine (z) and disclosed

long_data_disclosed <- rbind(long_data_disclosed, long_data_undisclosed_z)



#############################################################
###Replacing undisclosed data with estimates - 5 steps within
#############################################################

######Step 1: Sum disclosed acres per crop per state
tbl_df(long_data_disclosed)
#Crop_by_State_disclosed = sum of the county-level disclosed acres per crop per state
Crop_by_State_disclosed <- (long_data_disclosed  
                              %>%   group_by(Data.Item, State) 
                                %>%   summarise(disclosed_sum  = sum(Value)))

######Step 2: Subtract (sum disclosed acres per crop per state from step 1) from 
 # (state's total harvested acres for a commodity)
#State total area per crop (all 21 crops)
state <- state %>%
  select(keep_col)%>%
  filter(State != "ALASKA" & State != "HAWAII")

#rename data.items
state$Data.Item <- ifelse(state$Data.Item == "APPLES - ACRES BEARING","apples",
                        ifelse(state$Data.Item == "BARLEY - ACRES HARVESTED" ,"barley",
                         ifelse(state$Data.Item == "BEANS, DRY EDIBLE, (EXCL LIMA) - ACRES HARVESTED","beans",
                          ifelse(state$Data.Item == "CANOLA - ACRES HARVESTED","canola",
                           ifelse(state$Data.Item == "CORN, GRAIN - ACRES HARVESTED","corn_grain",
                            ifelse(state$Data.Item == "CORN, SILAGE - ACRES HARVESTED","corn_silage",
                            ifelse(state$Data.Item == "COTTON - ACRES HARVESTED","cotton",
                            ifelse(state$Data.Item == "HAY - ACRES HARVESTED","hay",
                            ifelse(state$Data.Item == "HAY, ALFALFA - ACRES HARVESTED","alfalfa",
                            ifelse(state$Data.Item == "ORANGES - ACRES BEARING","oranges",
                            ifelse(state$Data.Item ==  "PEANUTS - ACRES HARVESTED","peanuts",
                            ifelse(state$Data.Item == "POTATOES - ACRES HARVESTED","potatoes",
                            ifelse(state$Data.Item == "RICE - ACRES HARVESTED","rice",
                            ifelse(state$Data.Item == "SORGHUM, GRAIN - ACRES HARVESTED","sorghum",
                            ifelse(state$Data.Item == "SOYBEANS - ACRES HARVESTED","soybeans",
                            ifelse(state$Data.Item == "SUGARBEETS - ACRES HARVESTED","sugarbeets",
                            ifelse(state$Data.Item == "SUGARCANE, SUGAR - ACRES HARVESTED","sugarcane",
                            ifelse(state$Data.Item == "SUNFLOWER - ACRES HARVESTED","sunflower",
                            ifelse(state$Data.Item == "SWEET CORN - ACRES HARVESTED","sweet_corn",
                            ifelse(state$Data.Item == "TOBACCO - ACRES HARVESTED","tobacco",
                            ifelse(state$Data.Item == "WHEAT - ACRES HARVESTED","wheat","NA")))))))))))))))))))))


#split dataframe, revise undisclosed data to -99, change values to integers, recombine
#56 crop/state combos undisclosed
state_undisclosed <- state%>%
  filter(Value == " (D)" | Value == " (Z)")
state_disclosed <- state%>%
  filter(Value != " (D)" & Value != " (Z)")
state_disclosed$Value <- as.numeric(gsub(",","",state_disclosed$Value))


#create id to match on to perform linear fill from 2007 and 2002 for undisclosed
state_undisclosed$ID <- paste(state_undisclosed$State.ANSI,state_undisclosed$Data.Item)

#Linear fill for missing 2012 state total acres per crop (using 2002 and 2007 data)
#rename data.items
state_total_0702$Data.Item <- ifelse(state_total_0702$Data.Item == "APPLES - ACRES BEARING","apples",
                               ifelse(state_total_0702$Data.Item == "BARLEY - ACRES HARVESTED" ,"barley",
                               ifelse(state_total_0702$Data.Item == "BEANS, DRY EDIBLE, (EXCL LIMA) - ACRES HARVESTED","beans",
                                ifelse(state_total_0702$Data.Item == "CANOLA - ACRES HARVESTED","canola",
                                 ifelse(state_total_0702$Data.Item == "CORN, GRAIN - ACRES HARVESTED","corn_grain",
                                  ifelse(state_total_0702$Data.Item == "CORN, SILAGE - ACRES HARVESTED","corn_silage",
                                   ifelse(state_total_0702$Data.Item == "COTTON - ACRES HARVESTED","cotton",
                                    ifelse(state_total_0702$Data.Item == "HAY - ACRES HARVESTED","hay",
                                     ifelse(state_total_0702$Data.Item == "HAY, ALFALFA - ACRES HARVESTED","alfalfa",
                                       ifelse(state_total_0702$Data.Item == "ORANGES - ACRES BEARING","oranges",
                                        ifelse(state_total_0702$Data.Item ==  "PEANUTS - ACRES HARVESTED","peanuts",
                                         ifelse(state_total_0702$Data.Item == "POTATOES - ACRES HARVESTED","potatoes",
                                          ifelse(state_total_0702$Data.Item == "RICE - ACRES HARVESTED","rice",
                                           ifelse(state_total_0702$Data.Item == "SORGHUM, GRAIN - ACRES HARVESTED","sorghum",
                                            ifelse(state_total_0702$Data.Item == "SOYBEANS - ACRES HARVESTED","soybeans",
                                             ifelse(state_total_0702$Data.Item == "SUGARBEETS - ACRES HARVESTED","sugarbeets",
                                              ifelse(state_total_0702$Data.Item == "SUGARCANE, SUGAR - ACRES HARVESTED","sugarcane",
                                               ifelse(state_total_0702$Data.Item == "SUNFLOWER - ACRES HARVESTED","sunflower",
                                                ifelse(state_total_0702$Data.Item == "SWEET CORN - ACRES HARVESTED","sweet_corn",
                                                 ifelse(state_total_0702$Data.Item == "TOBACCO - ACRES HARVESTED","tobacco",
                                                  ifelse(state_total_0702$Data.Item == "WHEAT - ACRES HARVESTED","wheat","NA")))))))))))))))))))))


state_total_0702 <- state_total_0702[,c(2,6,7,17,20)]
state_total_0702$ID <- paste(state_total_0702$State.ANSI,state_total_0702$Data.Item)
state_total_2007 <- state_total_0702[which(state_total_0702$Year == 2007),]
state_total_2002 <- state_total_0702[which(state_total_0702$Year == 2002),]

#For 2007
state_total_2007_filt <-  subset(state_total_2007, state_total_2007$ID %in% state_undisclosed$ID)
state_total_2007_filt <- state_total_2007_filt[,c(5,6)]
state_total_2007_filt<- rename(state_total_2007_filt, Value.2007 = Value)
state_undisclosed <- left_join( state_undisclosed, state_total_2007_filt,
                        by = c("ID" = "ID"))
#For 2002
state_total_2002_filt <-  subset(state_total_2002, state_total_2002$ID %in% state_undisclosed$ID)
state_total_2002_filt <- state_total_2002_filt[,c(5,6)]
state_total_2002_filt<- rename(state_total_2002_filt, Value.2002 = Value)
state_undisclosed <- left_join( state_undisclosed, state_total_2002_filt,
                                by = c("ID" = "ID"))

state_undisclosed$Value.2007 <- as.numeric(gsub(",","",state_undisclosed$Value.2007))
state_undisclosed$Value.2002 <- as.numeric(gsub(",","",state_undisclosed$Value.2002))

#Fill missing values (went from 56 missing to 31)
state_undisclosed$Value <- ifelse(!is.na(state_undisclosed$Value.2007),
                                     state_undisclosed$Value.2007, 
                                     state_undisclosed$Value.2002)
state_undisclosed <- state_undisclosed[,1:6]
rm(state_total_0702, state_total_2002, state_total_2002_filt, state_total_2007,
   state_total_2007_filt)
#combine filled data back with disclosed data
state_disclosed$Value <- as.numeric(gsub(",","",state_disclosed$Value))
#State_total_area_crop = reported state level acreage per commodity 
State_total_area_crop <- rbind(state_undisclosed, state_disclosed)
#order by crop and then state
State_total_area_crop  <- State_total_area_crop [order(State_total_area_crop $Data.Item,
                                                       State_total_area_crop $State),]
#check to see that only has 31 missing values
#length(which(is.na(State_total_area_crop$Value) == "TRUE"))
#rename value column to total_harvested_acre_per_crop)
colnames(State_total_area_crop )[colnames(State_total_area_crop )=="Value"] <- "total_harvested_acre_per_crop"
#combine disclosed_sum per crop and total_harvested_acre_per_crop data into one table
Remainder <- left_join( State_total_area_crop , Crop_by_State_disclosed,
          by = c("State" = "State", "Data.Item" = "Data.Item"))

#If disclosed_sum = NA in Remainder, change value to 0 (representing the fact that 
  #there is no disclosed acreage, it is all undisclosed or does not exist)
#Which counties have all undisclosed counties/crop
all_undisclosed <- Remainder[is.na(Remainder$disclosed_sum),]
all_undisclosed <- all_undisclosed[order(all_undisclosed$total_harvested_acre_per_crop),]
Remainder <- Remainder[order(Remainder$disclosed_sum),]
Remainder_nona <- Remainder%>%
  filter(!is.na(disclosed_sum))
Remainder_na <- Remainder%>%
  filter(is.na(disclosed_sum))
Remainder_na$disclosed_sum <- 0
Remainder <- rbind(Remainder_nona, Remainder_na)
#check for nas in Remainder
#length(which(is.na(Remainder$disclosed_sum)))

#Subtract disclosed_sum per crop from total_harvested_acre_per_crop

#check that all total_harvested_acre_per_crop's are larger than the disclosed_sum 
  #not true - Vermont and Connecticut are off by 1 acre
#View(Remainder[which(Remainder$disclosed_sum > Remainder$total_harvested_acre_per_crop),])

#Note that 31 rows have total_harvested_acres_per_crop as NA these will still be NA
Remainder <- mutate(Remainder, remainder = total_harvested_acre_per_crop - disclosed_sum)
Remainder <- Remainder[order(Remainder$Data.Item, Remainder$State),]

#Check for negative remainders - should be Vermont and Connecticut
#View(Remainder[which(Remainder$remainder < 0),])
#Change the 2 values that are "-1" to zero (they were off by 1 acre, so essenetialy remainder equals zero)
Remainder$remainder <- ifelse(Remainder$remainder == -1, 0,Remainder$remainder)

rm("all_undisclosed","Remainder_nona","Remainder_na")

#####Step 3: Sum total cropland acres in undisclosed counties per state per commodity
county <- county %>%
  select(keep_col)%>%
  filter(State != "ALASKA" & State != "HAWAII")

#split dataframe, revise undisclosed data to -99, change values to integers, recombine
county_undisclosed <- county%>%
  filter(Value == " (D)" | Value == " (Z)")
county_disclosed <- county%>%
  filter(Value != " (D)" & Value != " (Z)")
county_disclosed$Value <- as.numeric(gsub(",","",county_disclosed$Value))

#create id to match on to perform linear fill from 2007 and 2002 for undisclosed
county_undisclosed$ID <- paste(county_undisclosed$State.ANSI,"_",county_undisclosed$County.ANSI)

#For counties missing 2012 total county acres, fill wih 2002 and 2007 (and make ID)
county_total_0702 <- county_total_0702[,c(2,6,7,10,11,17,20)]
county_total_0702$ID <- paste(county_total_0702$State.ANSI,"_",county_total_0702$County.ANSI)
county_total_2007 <- county_total_0702[which(county_total_0702$Year == 2007),]
county_total_2002 <- county_total_0702[which(county_total_0702$Year == 2002),]

#For 2007
county_total_2007_filt <-  subset(county_total_2007, county_total_2007$ID %in% county_undisclosed$ID)
county_total_2007_filt <- county_total_2007_filt[,c(7,8)]
county_total_2007_filt<- rename(county_total_2007_filt, Value.2007 = Value)
county_undisclosed <- left_join( county_undisclosed, county_total_2007_filt,
                                by = c("ID" = "ID"))
#For 2002
county_total_2002_filt <-  subset(county_total_2002, county_total_2002$ID %in% county_undisclosed$ID)
county_total_2002_filt <- county_total_2002_filt[,c(7,8)]
county_total_2002_filt<- rename(county_total_2002_filt, Value.2002 = Value)
county_undisclosed <- left_join( county_undisclosed, county_total_2002_filt,
                                by = c("ID" = "ID"))

county_undisclosed$Value.2007 <- as.numeric(gsub(",","",county_undisclosed$Value.2007))
county_undisclosed$Value.2002 <- as.numeric(gsub(",","",county_undisclosed$Value.2002))

#Fill missing values
county_undisclosed$Value <- ifelse(!is.na(county_undisclosed$Value.2007),
                                  county_undisclosed$Value.2007, 
                                  county_undisclosed$Value.2002)
county_undisclosed <- county_undisclosed[,1:6]

rm(county_total_0702, county_total_2002, county_total_2002_filt, county_total_2007,
   county_total_2007_filt)
#combine filled data back with disclosed data (Went from 86 missing to 16 missing)
county_disclosed$Value <- as.numeric(gsub(",","",county_disclosed$Value))
#total_county_cropland is reported county total harvest cropland (all crops)
total_county_cropland <- rbind(county_undisclosed, county_disclosed)
total_county_cropland$ID <- paste(total_county_cropland$State,
                        total_county_cropland$County, sep="_")
total_county_cropland <- total_county_cropland[order(total_county_cropland$State,
                                                     total_county_cropland$County),]

#Create new dataframe (TCC) with just ANSI and total_county_cropland_acres to be 
  #used to make 22nd variable
TCC <- total_county_cropland
TCC$State.ANSI<- formatC(TCC$State.ANSI, width = 2, format = "d", flag = "0")
TCC$County.ANSI <- formatC(TCC$County.ANSI, width = 3, format = "d", flag = "0")
TCC$ANSI<- paste(TCC$State.ANSI, TCC$County.ANSI, sep = "")
TCC$ANSI<- as.factor(TCC$ANSI)
colnames(TCC)[6] <- "total_county_cropland_acres"
TCC <- TCC[,c(8,6)]

#Get list of undisclosed counties sorted by commodity, state, county
long_data_undisclosed <- long_data_undisclosed[order(long_data_undisclosed$Data.Item,
                                                     long_data_undisclosed$State,
                                                     long_data_undisclosed$County),]
long_data_undisclosed$total_county_cropland <- -99
long_data_undisclosed$ID <- paste(long_data_undisclosed$State,
                                    long_data_undisclosed$County, sep="_")
#Fill in table of undisclosed counties with total cropland per county
long_data_undisclosed$total_county_cropland <- 
  total_county_cropland[match(long_data_undisclosed$ID, total_county_cropland$ID), "Value"] 

#Calculate sum of total cropland per undisclosed counties by crop
#total_cropland_acres_in_undisclosed_counties is the sum of undisclosed counties total harvested cropland
undisclosed_county_totals <- (long_data_undisclosed  
                            %>%   group_by(Data.Item, State) 
                            %>%   summarise(total_cropland_acres_in_undisclosed_counties = sum(total_county_cropland, na.rm =TRUE)))
#check
#View(long_data_undisclosed[which(long_data_undisclosed$State ==
 #"ALABAMA" & long_data_undisclosed$Data.Item =="apples"),])



#####Step 4
#Calculated coefficient for state-based estimates
#Divide remainder by total_cropland_acres_in_undisclosed_counties
#(sum of total county acreage in all the undisclosed counties for a crop)
#first need to merge df
Remainder <- left_join(Remainder, undisclosed_county_totals, 
          by = c("State" = "State", "Data.Item" = "Data.Item") )
#Make new variable "coeff" that is the remainder divided by total_cropland_acres_in_undisclosed_counties
Remainder <- mutate(Remainder, coeff = remainder/total_cropland_acres_in_undisclosed_counties)


#####Step 5
#Determine estimate for (D) & (Z) by multiplying the county total
#cropland acres by the state/crop level coefficient
#long_data_undisclosed has total_county_cropland
#make new ID in long_data_undisclosed and Remainder to match and 
#bring coeff into long_data_undisclosed
long_data_undisclosed$ID <- paste(long_data_undisclosed$State,
                                  long_data_undisclosed$Data.Item, sep="_")
Remainder$ID <- paste(Remainder$State,
                      Remainder$Data.Item, sep="_")
Remainder <- as.data.frame(Remainder)

#Check large coefficients (>1)
#View(Remainder[which(Remainder$coeff > 1),])
#adjust - if coeff >1, make coeff 1

Remainder$coeff <- ifelse(Remainder$coeff > 1, 1, Remainder$coeff)

#create new coeff column in long_data_undisclosed using match
long_data_undisclosed$coeff<- 
  Remainder[match(long_data_undisclosed$ID, Remainder$ID), "coeff"] 
#Multiply total_county_cropland by coefficient to get estimate
long_data_undisclosed <- mutate(long_data_undisclosed,
                                Value = total_county_cropland * coeff)
long_data_undisclosed_short<- long_data_undisclosed[,keep_col]


######

##########################################
#######Recombine dataset with estimates
########################################
#drop ANSI column from long_data_disclosed to match
long_data_disclosed <- long_data_disclosed[,-7]
long_data_complete <- rbind(long_data_undisclosed_short,long_data_disclosed)
#Pad .ANSI to be 2 and 3 characters
long_data_complete$State.ANSI<- formatC(long_data_complete$State.ANSI, width = 2, format = "d", flag = "0")
long_data_complete$County.ANSI <- formatC(long_data_complete$County.ANSI, width = 3, format = "d", flag = "0")
long_data_complete$ANSI<- paste(long_data_complete$State.ANSI, long_data_complete$County.ANSI, sep = "")
long_data_complete$ANSI<- as.factor(long_data_complete$ANSI)
#subset data
long_data_for_dcast <- long_data_complete[,c(7,5,6)]

#Spread out crop data by variable
#wide_data <- dcast(long_data_num_pos, State + County ~ Data.Item, value.var = "Value", fill = 0)
wide_data <- dcast(long_data_for_dcast, ANSI ~ Data.Item,
                   value.var = "Value", fill = 0)

#Correct for Hay and alfalfa overlap

wide_data <- mutate(wide_data, hay = hay - alfalfa)

rm("long_data_undisclosed_short","long_data_for_dcast")

#take back out to long_form for checks 
long_data_complete <- melt(wide_data, id.vars = "ANSI")
long_data_complete$State.ANSI <- as.character(substr(long_data_complete$ANSI,
                                                     start = 1, stop = 2))
### Make 22nd crop with Wide data
#Add county total acreage here
wide_data_TCC <- left_join(wide_data, TCC, by = c("ANSI" = "ANSI"))

#sum all 21 crops
wide_data_TCC <- mutate(wide_data_TCC, est_21crop_acres = apples + barley + alfalfa + canola +
                          beans + corn_grain + corn_silage + cotton + oranges +
                          peanuts + potatoes + rice + sorghum + soybeans + sugarbeets + 
                          sugarcane + sunflower + sweet_corn + tobacco + wheat + hay)
#subtract sum of all crops from county total acreage
wide_data_TCC <- mutate(wide_data_TCC, crop_22 = total_county_cropland_acres - est_21crop_acres)
#765 crop_22 are negative, which means that we overestimated total county cropland with our
  #21 crops in those counties.
#View(wide_data_TCC[which(wide_data_TCC$crop_22 < 0),])



#If result is negative (more acreage accounted for than total county acreage) change to 0
which(wide_data_TCC$crop_22 < 0)
wide_data_TCC$crop_22_adj = wide_data_TCC$crop_22
wide_data_TCC$crop_22_adj[which(wide_data_TCC$crop_22_adj < 0)] <- 0




##################################################################################
#Create crop percent composition variables (percent county cropland in given crop)
##################################################################################
#####Percent acreage with 21nd crop
#start with wide_data_TCC
#Sum all 21 crops plus the 21nd crop
wide_data_TCC <- mutate(wide_data_TCC, est_22crop_acres = apples + alfalfa + barley + canola +
         beans + corn_grain + corn_silage + cotton + oranges +
         peanuts + potatoes + rice + sorghum + soybeans + sugarbeets + 
         sugarcane + sunflower + sweet_corn + tobacco + wheat + hay + crop_22_adj)

#write function to divide rowwise by total_county_cropland
PercentAcres <- function(crop,total_acres) {
  percent <- (crop/total_acres)
  
}

wide_data_percent_22 <- mapply(PercentAcres, crop = wide_data_TCC[c(2:22,26)],
                               total_acres = wide_data_TCC[27])
wide_data_percent_22 <- cbind(wide_data_TCC[1], wide_data_percent_22)
#Check to make sure percents add to 1
#rowSums(wide_data_percent_22[,2:23])

#Add State and County names back to wide_data_TCC
county$State.ANSI<- formatC(county$State.ANSI, width = 2, format = "d", flag = "0")
county$County.ANSI <- formatC(county$County.ANSI, width = 3, format = "d", flag = "0")
county$ANSI<- paste(county$State.ANSI, county$County.ANSI, sep = "")
county$ANSI<- as.factor(county$ANSI)
state_county <- county[,c(1,2,3,7)]

wide_data_complete <- left_join(wide_data_TCC, state_county, by = c("ANSI" = "ANSI"))
#Reorder dataset
wide_data_complete <- wide_data_complete[,c(1,28:30,2:27)]

######
#Save data and output to form for second script
#Data with identifiers
write.csv(wide_data_complete,"Wide_data_final.csv")
#Data script for clustering
write.csv(wide_data_percent_22,"22crop_percent_data_to_cluster_final.csv")



######




#######################
#Quality Control Checks
#######################


#check for NAs in dataframe
length(which(is.na(wide_data_complete[,2:22])))

######
######Check 1 - state total acreage
######
state_rep_total_acres <- state_rep_total_acres[,keep_col]
state_rep_total_acres$Value <- as.numeric(gsub(",","",state_rep_total_acres$Value))
state_rep_total_acres$State.ANSI<- formatC(state_rep_total_acres$State.ANSI, width = 2, format = "d", flag = "0")

#Check to make sure that total estimated acreage per state is not greater than reported
###Discuss these results with Eric and Meredith
estimate_state_total <- (wide_data_complete 
                              %>%   group_by(State.ANSI) 
                              %>%   summarise(est_total_cropland= sum(est_22crop_acres,na.rm =TRUE)))

state_total_comp <- left_join(estimate_state_total, state_rep_total_acres, 
                       by = c("State.ANSI" = "State.ANSI") )
state_total_comp <- mutate(state_total_comp, delta =  Value - est_total_cropland)
state_total_comp <- mutate(state_total_comp, delta.percent = delta/Value *100)
min(state_total_comp$delta.percent)
max(state_total_comp$delta.percent)
mean(state_total_comp$delta.percent)
median(state_total_comp$delta.percent)
hist(state_total_comp$delta.percent)

plot_state_total_estimates <- ggplot(data=state_total_comp, aes(x=est_total_cropland,y=Value), color=category) + 
  geom_jitter(aes(y =Value), size = 3, alpha = 1) +
  ylab("Reported State Total Harvested Acres") +
  xlab("Estimated State Total Harvested Acres") + 
  geom_abline(slope=1, intercept = 0,linetype="dashed") +
  ggtitle("State Total Harvested Acres Estimates")

#regress estimated state total harvested acres on reported
check1 <- lm(Value ~ est_total_cropland,data = state_total_comp)
summary(check1)

#Check for underestimates:
#View(state_total_comp[which(state_total_comp$delta.percent > 1),])
#Investigating Rhode Island, underestimated by 22%
#Which data items are in the dataset?
#View(long_data[which(long_data$State.ANSI == "44"),])
test<-long_data[which(long_data$State.ANSI == "44"),]
#ANSI - 44005,44009, 44001
unique(test$ANSI)
#Which got dropped?
test_raw <- long_data_raw[which(long_data_raw$State.ANSI == "44"),]
#five counties, 7 & 3 got dropped
unique(test_raw$County.ANSI)
RI_lost_counties <- test_raw[which(test_raw$County.ANSI == 7 | test_raw$County.ANSI == 3),]
RI_lost_counties$Value <- as.numeric(gsub(",","",RI_lost_counties$Value))
sum(RI_lost_counties$Value,na.rm = TRUE)


#5 estimates are right on - delta is zero
#View(state_total_comp[which(state_total_comp$delta.percent == 0),])

#12 state are more than 3% overestimated
#largest is Delaware at 16% over
#View(state_total_comp[which(state_total_comp$delta.percent < -3),])
test<-long_data[which(long_data$State.ANSI == "10"),]
#ANSI - 10001, 10003, 10005
unique(test$ANSI)

#Which got dropped? 
test_raw <- long_data_raw[which(long_data_raw$State.ANSI == "10"),]
unique(test_raw$County.ANSI)
#raw sum (without undisclosed estimates)
test_raw$Value <- as.numeric(gsub(",","",test_raw$Value))
sum(test_raw$Value,na.rm = TRUE)

#for delaware, look at total state acreage estimated from state level crop totals
state_total_acreage_from_crop_total <- (state_disclosed  %>%
                     group_by(State.ANSI) %>% 
                     summarise(state_total_from_crop_total= sum(Value)))
#494,222
state_total_acreage_from_crop_total[which(
        state_total_acreage_from_crop_total$State.ANSI == "10"),]
#Subtract off state total alfalfa value to account for double counting (4873)=489,385

######
#####Check 2 - state per commodity acreage - ALL VALUES MATCH UP - no error (except for hay - fix)
######
#Check to make sure that total estimated acreage per commodity per state is not greater than reported
#create estimate crop total acreage per state
est_crop_total <- (long_data_complete %>%
                           group_by(State.ANSI, variable)  %>%
                           summarise(est_crop_total= sum(value)))


#reported crop total acreage per state
#Correct for state level overlap of hay and alfalfa
rep_crop_total <- (state_disclosed  %>%
                         group_by(State.ANSI, Data.Item) %>% 
                            summarise(rep_crop_total= sum(Value)))
#go wide 
rep_crop_total_wide <-  dcast(rep_crop_total, State.ANSI ~ Data.Item,
                              value.var = "rep_crop_total", fill = 0)
#subtract off alfalfa from hay
rep_crop_total_wide <- mutate(rep_crop_total_wide, hay = hay - alfalfa)
#go long again
rep_crop_total <- melt(rep_crop_total_wide, id.vars = "State.ANSI")


#make State.ANSI variable matchable
rep_crop_total$State.ANSI<- formatC(rep_crop_total$State.ANSI, width = 2, format = "d", flag = "0")
#join estimate and reported
state_crop_total <- left_join(est_crop_total, rep_crop_total, 
                              by = c("State.ANSI" = "State.ANSI", "variable" = "variable") )
state_crop_total  <- mutate(state_crop_total , delta =  value - est_crop_total)
state_crop_total <- mutate(state_crop_total,delta.percent = delta/value *100)
state_crop_total$delta.percent <- round(state_crop_total$delta.percent, digits = 2)
min(state_crop_total$delta.percent, na.rm = TRUE)
max(state_crop_total$delta.percent, na.rm = TRUE)
mean(state_crop_total$delta.percent, na.rm = TRUE)
median(state_crop_total$delta.percent, na.rm = TRUE)
hist(state_crop_total$delta.percent, breaks = 100)


#plot of estimates vs reported for paper

plot_state_estimates <- ggplot(data=state_crop_total, aes(x=est_crop_total,y=value), color=category) + 
  geom_jitter(aes(y = value), size = 3, alpha = 1) +
  ylab("Reported State Total Acreage per crop") +
  xlab("Estimated State Total Acreage per crop") + 
  geom_abline(slope=1, intercept = 0,linetype="dashed") +
  ggtitle("State Crop Acreage Estimates")

#regress
check2 <- lm(value ~ est_crop_total, data = state_crop_total)
summary(check2)

#check for outliers
View(state_crop_total[which(state_crop_total$delta.percent > 1),])

#Check colorado & hay
#View(long_data_raw[which(long_data_raw$State.ANSI == "8" &
  #                         long_data_raw$Data.Item == "HAY - ACRES HARVESTED"), ])
#View(long_data_raw[which(long_data_raw$State.ANSI == "8" &
 #                        long_data_raw$Data.Item == "HAY, ALFALFA - ACRES HARVESTED"), ])
#View(Remainder[which(Remainder$State.ANSI == "8"),])


#No underestimates
#View(state_crop_total[which(state_crop_total$delta.percent <0),])

#####
#####Check 3 - county total acreage
#####
##### Hay is corrected for in these calculations (alfalfa and hay_other)
#wide_data_TCC$total_county_cropland_acres is reported and filled total county cropland
#wide_data_TCC$est_21crop_acres is the estimated acreage using just the 21 crops
#wide_data_TCC$crop_22 is the difference between total county cropland and the estimate
#wide_data_TCC$perc_off is the percentage difference (negative is over estimate)


#Percent off
wide_data_TCC <- mutate(wide_data_TCC, perc_off = (((total_county_cropland_acres - est_22crop_acres)/total_county_cropland_acres)*100))
  
wide_data_TCC <- mutate(wide_data_TCC, delta = (total_county_cropland_acres - est_22crop_acres))

#Those more than 10 percent overestimated - 144
#View(wide_data_TCC[which(wide_data_TCC$perc_off < -50 ),])

#View(wide_data_TCC[which(wide_data_TCC$delta < -10000 ),])


min(wide_data_TCC$perc_off, na.rm = TRUE)
max(wide_data_TCC$perc_off, na.rm = TRUE)
mean(wide_data_TCC$perc_off, na.rm = TRUE)
median(wide_data_TCC$perc_off, na.rm = TRUE)
hist(wide_data_TCC$perc_off, breaks = 100)
hist(wide_data_TCC$perc_off, breaks = 100)

plot_county_total_estimates <- ggplot(data=wide_data_TCC, aes(x=est_22crop_acres,y=total_county_cropland_acres), color=category) + 
  geom_jitter(aes(y =total_county_cropland_acres), size = 3, alpha = 1) +
  ylab("Reported County Total Harvested Acres") +
  xlab("Estimated County Total Harvested Acres") + 
  geom_abline(slope=1, intercept = 0,linetype="dashed") +
  ggtitle("County Total Harvested Acres Estimates")

#check3
check3 <- lm(total_county_cropland_acres ~ est_22crop_acres, data = wide_data_TCC)
summary(check3)

#Examine outliers - 08053 is 166% off 
#initial download - 1032 acres for hay, only has 387 acres reported for total county cropland
#View(long_data_raw[which(long_data_raw$State.ANSI == "8" & long_data_raw$County.ANSI == "53"),])


#Examine outliers - 20021, 21047, 21141, 37179, 47053 have 40,000+ overestimate
#View(long_data_raw[which(long_data_raw$State.ANSI == "20" & long_data_raw$County.ANSI == "21"),])






######